@@ -24,26 +24,38 @@
 /* main.cpp */
 
 #include <kapp.h>
+#include <signal.h>
 
 #include "mainwidget.h"
 
 int main( int argc, char **argv )
 {
-   if( !FirstInstance() )
-   {
-      return 0;
-   }
-   else
-   {
-	   KApplication app( argc, argv, "kwebwatch" );
-	   MainWidget w;
-	
-	   app.setMainWidget( &w );
-	
-	   //if( !w.StartingDocked() )
-	   //   w.show();
-   		
-	   return app.exec();
+    long pid;
+
+    if( !FirstInstance(&pid) )
+    {
+	if( argc > 1 && argv[1][1] == 'k')
+	{
+	    if( 0 == kill( pid, SIGKILL))
+		printf("kwebwatch: killed process %ld successfully\n", pid);
+	    else
+		printf("kwebwatch: failed to kill process %ld\n", pid);
 	}
+	return 0;
+    }
+    else
+    {
+	if( argc > 1 && argv[1][1] == 'k')
+	{
+	    printf("kwebwatch: nothing to kill\n");
+	    return 0;
+	}
+
+	KApplication app( argc, argv, "kwebwatch" );
+	MainWidget w;
+	app.setMainWidget( &w );
+	
+	return app.exec();
+    }
 }
 
